[med-svn] [r-bioc-limma] 02/05: Imported Upstream version 3.24.15+dfsg

Andreas Tille tille at debian.org
Fri Sep 25 20:02:38 UTC 2015


This is an automated email from the git hooks/post-receive script.

tille pushed a commit to branch master
in repository r-bioc-limma.

commit 1ef4bdd0ea22d61466a7d0c2d6a25d220538f375
Author: Andreas Tille <tille at debian.org>
Date:   Fri Sep 25 21:53:43 2015 +0200

    Imported Upstream version 3.24.15+dfsg
---
 DESCRIPTION                 |   6 +++---
 R/kegga.R                   |  24 ++++++++++++------------
 inst/doc/changelog.txt      |   4 ++++
 inst/doc/intro.pdf          | Bin 46191 -> 46191 bytes
 man/goana.Rd                |   2 +-
 man/topGO.Rd                |   9 +++++----
 tests/limma-Tests.Rout.save |  14 +++++++++++---
 7 files changed, 36 insertions(+), 23 deletions(-)

diff --git a/DESCRIPTION b/DESCRIPTION
index 17e28c2..306a9fa 100755
--- a/DESCRIPTION
+++ b/DESCRIPTION
@@ -1,6 +1,6 @@
 Package: limma
-Version: 3.24.14
-Date: 2015-07-20
+Version: 3.24.15
+Date: 2015-08-05
 Title: Linear Models for Microarray Data
 Description: Data analysis, linear models and differential expression for microarray data.
 Author: Gordon Smyth [cre,aut], Matthew Ritchie [ctb], Jeremy Silver [ctb], James Wettenhall [ctb], Natalie Thorne [ctb], Davis McCarthy [ctb], Di Wu [ctb], Yifang Hu [ctb], Wei Shi [ctb], Belinda Phipson [ctb], Alicia Oshlack [ctb], Carolyn de Graaf [ctb], Mette Langaas [ctb], Egil Ferkingstad [ctb], Marcus Davy [ctb], Francois Pepin [ctb], Dongseok Choi [ctb], Aaron Lun [ctb]
@@ -20,4 +20,4 @@ biocViews: ExonArray, GeneExpression, Transcription,
         MultipleComparison, Normalization, Preprocessing,
         QualityControl
 NeedsCompilation: yes
-Packaged: 2015-07-21 01:24:42 UTC; biocbuild
+Packaged: 2015-08-06 01:23:12 UTC; biocbuild
diff --git a/inst/doc/changelog.txt b/inst/doc/changelog.txt
index 8dcb976..dfd4b2c 100755
--- a/inst/doc/changelog.txt
+++ b/inst/doc/changelog.txt
@@ -1,3 +1,7 @@
+ 5 Aug 2015: limma 3.24.15
+
+- argument truncate.term for topKEGG() renamed to 'truncate.path'.
+
 20 July 2015: limma 3.24.14
 
 - camera() has a new argument inter.gene.cor.  This allows a preset
diff --git a/inst/doc/intro.pdf b/inst/doc/intro.pdf
index b94678c..65a3286 100644
Binary files a/inst/doc/intro.pdf and b/inst/doc/intro.pdf differ
diff --git a/man/goana.Rd b/man/goana.Rd
index 8466649..4fccbfb 100644
--- a/man/goana.Rd
+++ b/man/goana.Rd
@@ -86,7 +86,7 @@ The \code{goana} method for \code{MArrayLM} objects produces a data frame with a
 
 The row names of the data frame give the GO term IDs.
 
-The output from \code{kegga} is the same except that row names become KEGG pathway IDs, \code{Term} becomes \code{Path} and there is no \code{Ont} column.
+The output from \code{kegga} is the same except that row names become KEGG pathway IDs, \code{Term} becomes \code{Pathway} and there is no \code{Ont} column.
 }
 
 \references{
diff --git a/man/topGO.Rd b/man/topGO.Rd
index 54648c1..2101901 100644
--- a/man/topGO.Rd
+++ b/man/topGO.Rd
@@ -4,21 +4,22 @@
 \title{Table of Top GO Terms or Top KEGG Pathways}
 
 \description{
-Extract top GO terms from goana output or top KEGG terms from kegga output.
+Extract top GO terms from goana output or top KEGG pathways from kegga output.
 }
 
 \usage{
 topGO(results, ontology = c("BP", "CC", "MF"), sort = NULL, number = 20L, 
       truncate.term = NULL)
-topKEGG(results, sort = NULL, number = 20L, truncate.term = NULL)
+topKEGG(results, sort = NULL, number = 20L, truncate.path = NULL)
 }
 
 \arguments{
-  \item{results}{data frame produced by \code{\link{goana}}.} 
+  \item{results}{data frame produced by \code{\link{goana}} or \code{\link{kegga}}.} 
   \item{ontology}{character vector of ontologies to be included in output.  Elements should be one or more of \code{"BP"}, \code{"CC"} or \code{"MF"}.}
   \item{sort}{character vector of names of gene lists for which results are required.  Should be one or more of the column names of \code{results}.  Defaults to all gene lists.}
-  \item{number}{maximum number of top GO terms to list. For all terms, set \code{number=Inf}.}
+  \item{number}{maximum number of top GO terms or top KEGG pathways to list. For all terms or all pathways, set \code{number=Inf}.}
   \item{truncate.term}{truncate the name of the GO term at this number of characters.}
+  \item{truncate.path}{truncate the name of the KEGG pathway at this number of characters.}
 }
 
 \details{
diff --git a/tests/limma-Tests.Rout.save b/tests/limma-Tests.Rout.save
index f1b47e5..1ac4959 100755
--- a/tests/limma-Tests.Rout.save
+++ b/tests/limma-Tests.Rout.save
@@ -1122,7 +1122,15 @@ attr(,"df1")
 attr(,"df2")
 [1] Inf
 > classifyTestsT(tstat)
-TestRe Median    Mean 3rd Qu.    Max. 
+TestRe.2900320 0.3006936 0.2935101 0.3646949 0.3596385 0.3064203
+ [64] 0.3027439 0.3076483 0.3363356 0.3504336 0.3496698 0.2897618 0.2898810
+ [71] 0.3182290 0.3121707 0.2945001 0.2897549 0.3579410 0.3434376 0.3037970
+ [78] 0.3201893 0.3048412 0.3394079 0.3516034 0.3034589 0.3120384 0.3007827
+ [85] 0.3013925 0.2902524 0.3527793 0.2969359 0.3033756 0.3170187 0.2978833
+ [92] 0.2908437 0.3139422 0.3050183 0.4727609 0.2897104 0.2931671 0.2904177
+ [99] 0.3231607 0.2941699
+> summary(fit$s2.post)
+   Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
  0.2518  0.2746  0.3080  0.3425  0.3583  0.7344 
 > 
 > y$E[1,1] <- NA
@@ -1252,7 +1260,7 @@ GO:0070062 0.055161144
 > proc.time()
    user  system elapsed 
    2.83    0.18    3.04 
-                                                                                                                       limma/vignettes/                                                                                    0000755 0001263 0001264 00000000000 12553317532 015252  5                                                                                                    ustar 00biocbuild                       phs_compbio                                                                  [...]
+                                                                                                                       limma/vignettes/                                                                                    0000755 0001263 0001264 00000000000 12560533400 015242  5                                                                                                    ustar 00biocbuild                       phs_compbio                                                                  [...]
 %\VignetteDepends{}
 %\VignetteKeywords{microarray linear model}
 %\VignettePackage{limma}
@@ -1301,4 +1309,4 @@ and follow the links to the limma package help.
 
 
 
-                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             [...]
\ No newline at end of file
+                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             [...]
\ No newline at end of file

diff --git a/R/kegga.R b/R/kegga.R
index bdfb813..4dd3d76 100644
--- a/R/kegga.R
+++ b/R/kegga.R
@@ -77,7 +77,7 @@ kegga.MArrayLM <- function(de, coef = ncol(de), geneid = rownames(de), FDR = 0.0
 kegga.default <- function(de, universe = NULL, species = "Hs", prior.prob = NULL, covariate=NULL, plot=FALSE, ...)
 #	KEGG (Kyoto Encyclopedia of Genes and Genomes) pathway analysis of DE genes
 #	Gordon Smyth and Yifang Hu
-#	Created 18 May 2015.  Modified 3 June 2015.
+#	Created 18 May 2015.  Modified 4 August 2015.
 {
 #	Ensure de is a list
 	if(!is.list(de)) de <- list(DE = de)
@@ -216,7 +216,7 @@ kegga.default <- function(de, universe = NULL, species = "Hs", prior.prob = NULL
 	pathname <- KEGGREST::keggList("pathway")
 	names(pathname) <- gsub("map", organism, names(pathname))
 	m <- match(g, names(pathname))
-	Results <- data.frame(Path = pathname[m], S, P, stringsAsFactors=FALSE)
+	Results <- data.frame(Pathway = pathname[m], S, P, stringsAsFactors=FALSE)
 	rownames(Results) <- g
 
 #	Name p-value columns
@@ -225,10 +225,10 @@ kegga.default <- function(de, universe = NULL, species = "Hs", prior.prob = NULL
 	Results
 }
 
-topKEGG <- function(results, sort = NULL, number = 20L, truncate.term=NULL)
+topKEGG <- function(results, sort = NULL, number = 20L, truncate.path=NULL)
 #	Extract top KEGG pathways from kegga output 
 #	Gordon Smyth and Yifang Hu
-#	Created 15 May 2015.
+#	Created 15 May 2015. Modified 4 August 2015.
 {
 #	Check results
 	if(!is.data.frame(results)) stop("results should be a data.frame.")
@@ -263,14 +263,14 @@ topKEGG <- function(results, sort = NULL, number = 20L, truncate.term=NULL)
 	}
 	tab <- results[o[1L:number],,drop=FALSE]
 
-#	Truncate Term column for readability
-	if(!is.null(truncate.term)) {
-		truncate.term <- as.integer(truncate.term[1])
-		truncate.term <- max(truncate.term,5L)
-		truncate.term <- min(truncate.term,1000L)
-		tm2 <- truncate.term-3L
-		i <- (nchar(tab$Term) > tm2)
-		tab$Term[i] <- paste0(substring(tab$Term[i],1L,tm2),"...")
+#	Truncate Pathway column for readability
+	if(!is.null(truncate.path)) {
+		truncate.path <- as.integer(truncate.path[1])
+		truncate.path <- max(truncate.path,5L)
+		truncate.path <- min(truncate.path,1000L)
+		tm2 <- truncate.path-3L
+		i <- (nchar(tab$Pathway) > tm2)
+		tab$Pathway[i] <- paste0(substring(tab$Pathway[i],1L,tm2),"...")
 	}
 
 	tab
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/debian-med/r-bioc-limma.git



More information about the debian-med-commit mailing list